# Rhasspy Profile

[![Continous Integration](https://github.com/rhasspy/rhasspy-profile/workflows/Tests/badge.svg)](https://github.com/rhasspy/rhasspy-profile/actions)
[![GitHub license](https://img.shields.io/github/license/rhasspy/rhasspy-profile.svg)](https://github.com/rhasspy/rhasspy-profile/blob/master/LICENSE)

Manages profiles settings for [Rhasspy](https://github.com/synesthesiam/rhasspy).
